Package: alacarte
Version: 0.13.2-3
Followup-For: Bug #635345

This patch allows alacarte to work without gnome-panel by using exo-desktop-
item-edit instead of gnome-desktop-item-edit. I tried it (using XFCE) and it
works fine.



-- System Information:
Debian Release: wheezy/sid
  APT prefers unstable
  APT policy: (500, 'unstable')
Architecture: amd64 (x86_64)

Kernel: Linux 3.2.0-2-amd64 (SMP w/4 CPU cores)
Locale: LANG=es_AR.UTF-8, LC_CTYPE=es_AR.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash

Versions of packages alacarte depends on:
ii  gnome-menus     3.2.0.1-2
ii  python          2.7.2-10
ii  python-gmenu    3.0.1-4
ii  python-gobject  3.2.0-3
ii  python-gtk2     2.24.0-3
ii  python-support  1.0.14

Versions of packages alacarte recommends:
pn  gnome-panel  <none>

alacarte suggests no packages.

-- no debconf information
--- MainWindow.py	2011-10-14 04:19:55.000000000 -0300
+++ MainWindow.py	2012-04-22 21:31:26.000000000 -0300
@@ -259,7 +259,7 @@
 			self.item_store.append((show, icon, name, item))
 
 	#this is a little timeout callback to insert new items after
 	#gnome-desktop-item-edit has finished running
 	def waitForNewItemProcess(self, process, parent, file_path):
 		if process.poll() != None:
 			if os.path.isfile(file_path):
@@ -269,7 +269,7 @@
 
 	def waitForNewMenuProcess(self, process, parent_id, file_path):
 		if process.poll() != None:
 			#hack for broken gnome-desktop-item-edit
 			broken_path = os.path.join(os.path.split(file_path)[0], '.directory')
 			if os.path.isfile(broken_path):
 				os.rename(broken_path, file_path)
@@ -295,7 +295,7 @@
 		else:
 			parent = menus[iter][2]
 		file_path = os.path.join(util.getUserDirectoryPath(), util.getUniqueFileId('alacarte-made', '.directory'))
-		process = subprocess.Popen(['gnome-desktop-item-edit', file_path], env=os.environ)
+		process = subprocess.Popen(['exo-desktop-item-edit', file_path], env=os.environ)
 		gobject.timeout_add(100, self.waitForNewMenuProcess, process, parent.menu_id, file_path)
 
 	def on_new_item_button_clicked(self, button):
@@ -308,7 +308,7 @@
 		else:
 			parent = menus[iter][2]
 		file_path = os.path.join(util.getUserItemPath(), util.getUniqueFileId('alacarte-made', '.desktop'))
-		process = subprocess.Popen(['gnome-desktop-item-edit', file_path], env=os.environ)
+		process = subprocess.Popen(['exo-desktop-item-edit', file_path], env=os.environ)
 		gobject.timeout_add(100, self.waitForNewItemProcess, process, parent, file_path)
 
 	def on_new_separator_button_clicked(self, button):
@@ -379,7 +379,7 @@
 			self.editor._MenuEditor__addUndo([item,])
 		if file_path not in self.edit_pool:
 			self.edit_pool.append(file_path)
-			process = subprocess.Popen(['gnome-desktop-item-edit', file_path], env=os.environ)
+			process = subprocess.Popen(['exo-desktop-item-edit', file_path], env=os.environ)
 			gobject.timeout_add(100, self.waitForEditProcess, process, file_path)
 
 	def on_menu_tree_cursor_changed(self, treeview):
@@ -259,7 +259,7 @@
 
 	#this is a little timeout callback to insert new items after
-	#gnome-desktop-item-edit has finished running
+	#exo-desktop-item-edit has finished running
 	def waitForNewItemProcess(self, process, parent, file_path):
 		if process.poll() != None:
@@ -269,7 +269,7 @@
 	def waitForNewMenuProcess(self, process, parent_id, file_path):
 		if process.poll() != None:
-			#hack for broken gnome-desktop-item-edit
+			#hack for broken exo-desktop-item-edit
 			broken_path = os.path.join(os.path.split(file_path)[0], '.directory')
 			if os.path.isfile(broken_path):

Reply via email to